/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : game.cpp
 */




#include "game.h"

#include <qtextstream.h>
#include <qstringlist.h>



Game::Game()
{
  init();
}

Game::~Game()
{
}

Game::Game( const Game& g )
{
  m_name = g.m_name;
  m_description = g.m_description;
  m_manufacturer = g.m_manufacturer;
  m_year = g.m_year;
  m_flags = g.m_flags;
  m_romof = g.m_romof;
  m_cloneof = g.m_cloneof;
  m_info = g.m_info;
  m_category = g.m_category;
}

Game& Game::operator=( const Game& g )
{
  m_name = g.m_name;
  m_description = g.m_description;
  m_manufacturer = g.m_manufacturer;
  m_year = g.m_year;
  m_flags = g.m_flags;
  m_romof = g.m_romof;
  m_cloneof = g.m_cloneof;
  m_info = g.m_info;
  m_category = g.m_category;
  return *this;
}

void Game::init()
{
  m_name = UnknownString;
  m_description = UnknownString;
  m_manufacturer = UnknownString;
  m_year = UnknownString;
  m_romof = "";
  m_cloneof = "";
  m_info = "";
  m_category = UnknownString;
  m_flags = Game::Unavailable;
}

bool Game::load( QTextStream* ts )
{
  QString sTmp = ts->readLine();
  if( sTmp.isNull() || sTmp.isEmpty() )
    return false;

  QStringList args = QStringList::split( "|", sTmp, true );
  m_name = args[0];
  m_description = args[1];
  m_manufacturer = args[2];
  m_year = args[3];
  m_flags = (args[4]).toLong();
  m_romof = args[5];
  m_cloneof = args[6];

  if( args.count() > 7 ) /* Since version 1.2.3 */
    m_category = args[7];

  return true;
}

void Game::save( QTextStream* ts )
{
  QStringList args;
  args.append( m_name );
  args.append( m_description );
  args.append( m_manufacturer );
  args.append( m_year );
  args.append( QString::number( m_flags ) );
  args.append( m_romof );
  args.append( m_cloneof );
  args.append( m_category );
  *ts << args.join( "|" ) << endl;
}

