/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : game.h
 */




#ifndef KAF_GAME_H
#define KAF_GAME_H

#include <qstring.h>
const QString UnknownString = "unknown";

class QTextStream;



class Game
{
public:
  enum Flag { Available = 1, Clone = 2, Runnable = 4, Favorite = 8,
              NeoGeo = 16, Original = 32, Unavailable = 64, Raster = 128,
              Vector = 256 };

  Game();
  ~Game();

  Game( const Game& );
  Game& operator=( const Game& );

  void init();

  QString& name() { return m_name; }
  QString& description() { return m_description; }
  QString& manufacturer() { return m_manufacturer; }
  QString& year() { return m_year; }
  QString& romof() { return m_romof; }
  QString& cloneof() { return m_cloneof; }
  QString& info() { return m_info; }
  QString& category() { return m_category; }

  void setFlag( Game::Flag flag ) { m_flags |= flag; }
  void removeFlag( Game::Flag flag ) { m_flags &= ~( flag ); }
  inline bool hasFlag( Game::Flag ) const;
  inline bool hasFlag( unsigned int ) const;

  bool load( QTextStream* );
  void save( QTextStream* );

private:
  QString m_name;
  QString m_description;
  QString m_manufacturer;
  QString m_year;
  QString m_romof;
  QString m_cloneof;
  QString m_info;
  QString m_category;

  unsigned long int m_flags;


};


inline bool Game::hasFlag( Game::Flag flag ) const
{
  return(  m_flags != 0 && ( m_flags & flag ) );
}

inline bool Game::hasFlag( unsigned int flag ) const
{
  return(  m_flags != 0 && ( m_flags & flag ) );
}

#endif /* KAF_GAME_H */

