/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : ksettings.cpp
 */




/***************************************************************************

    <!DOCTYPE KSettings> <KSettings version="0.1" application="" >
        <group name="General" >
            <option key="alpha" value="true" />
            <option key="beta" value="99" />
            <option key="gamma" value="test" />
        </group>
    </KSettings>

***************************************************************************/

#include "ksettings.h"

#include <qdom.h>
#include <qfile.h>
#include <qtextstream.h>



KSettings::KSettings( const QString& version, const QString& program_name )
{
  m_dirty = false;
  m_currentGroup = "General";
  m_file = "";
  m_format = program_name;
  m_version = version;
  m_buffer = "";
  m_fileState = false;
  m_formatState = false;
}

KSettings::~KSettings()
{
}

bool KSettings::getBool( const QString& key, bool def )
{
  m_buffer = getString( key, def ? "true" : "false");

  if( m_buffer.isEmpty() )
    return def;

  return ( m_buffer == "true" || m_buffer == "1" );
}

void KSettings::setBool( const QString& key, bool value )
{
  m_groups[ m_currentGroup ][ key ] = value ? "true" : "false";
  m_dirty = true;
}

long KSettings::getNumber( const QString& key, long def )
{
  m_buffer = getString( key, QString::number( def ) );

  if( m_buffer.isEmpty() )
    return def;

  bool ok;
  long num = m_buffer.toLong( &ok );
  if( ok )
    return num;
  else
    return def;
}

void KSettings::setNumber( const QString& key, long value )
{
  m_buffer.setNum( value );
  m_groups[ m_currentGroup ][ key ] = m_buffer;
  m_dirty = true;
}

double KSettings::getDouble( const QString& key, double def )
{
  m_buffer = getString( key, QString::number( def ) );
  if( m_buffer.isEmpty() )
    return def;

  bool ok;
  double num = m_buffer.toDouble( &ok );
  if( ok )
    return num;
  else
    return def;
}

void KSettings::setDouble( const QString& key, double value )
{
  m_buffer.setNum( value );
  m_groups[ m_currentGroup ][ key ] = m_buffer;
  m_dirty = true;
}

QString KSettings::getString( const QString& key, const QString& def )
{
  m_buffer = def;
  if( m_groups.contains( m_currentGroup ) )
  {
    if( m_groups[ m_currentGroup ].contains( key ) )
    {
      m_buffer = m_groups[ m_currentGroup ][key];
    }
  }

  return m_buffer;
}

void KSettings::setString( const QString& key, const QString& value )
{
  m_groups[ m_currentGroup ][ key ] = value;
  m_dirty = true;
}

bool KSettings::loadData()
{
  readData();
  return m_fileState && m_formatState;
}

bool KSettings::flush()
{
  if( m_dirty )
  {
    writeData();
    m_dirty = m_fileState;
  }

  return m_dirty;
}

void KSettings::readData()
{
  m_groups.clear();

  m_formatState = false;
  m_fileState = false;

  if( m_file.isEmpty() )
    return;

  QFile* pFile = new QFile( m_file );

  m_fileState = pFile->open( IO_ReadOnly );

  if( !m_fileState )
  {
    delete pFile;
    return;
  }

  QDomDocument doc( "KSettings" );

  m_formatState = doc.setContent( pFile, "" );

  pFile->close();
  delete pFile;

  if( !m_formatState )
    return;

  if( doc.doctype().name() != "KSettings" )
  {
    m_formatState = false;
    return;
  }

  QDomElement root = ( doc.documentElement() );
  if( root.attribute( "application" ) != m_format )
  {
    m_formatState = false;
    return;
  }

  /* For now we don't care about the version
  if( root.attribute( "version" ) != m_version )
  {
    m_formatState = false;
    return;
  }
  */

  QDomNodeList nodes = root.elementsByTagName( "group" );

  QDomNodeList options;

  for( unsigned int n = 0; n < nodes.count(); n++ )
    if( nodes.item( n ).isElement() )
      processGroup( nodes.item( n ).toElement() );

}

void KSettings::processGroup( QDomElement group )
{
  QDomElement elem;
  QDomNodeList options;
  m_currentGroup = group.attribute( "name", "General" );
  options = group.elementsByTagName( "option" );

  for( unsigned int n = 0; n < options.count(); n++ )
  {
    if( options.item( n ).isElement() )
    {
      elem = options.item( n ).toElement();
      setString( elem.attribute( "key" ), elem.attribute( "value" ) );
    }
  }
}

void KSettings::writeData()
{
  QDomDocument doc( "KSettings" );

  // create the root element
  QDomElement root = doc.createElement( doc.doctype().name() );
  root.setAttribute( "version", m_version );
  root.setAttribute( "application", m_format );

  // now do our options group by group
  QMap<QString, PrefMap>::Iterator git;
  PrefMap::Iterator pit;
  QDomElement group, option;
  for( git = m_groups.begin(); git != m_groups.end(); ++git )
  {
    // create a group element
    group = doc.createElement( "group" );
    group.setAttribute( "name", git.key() );
    // add in options
    for( pit = (*git).begin(); pit != (*git).end(); ++pit )
    {
      option = doc.createElement( "option" );
      option.setAttribute( "key", pit.key() );
      option.setAttribute( "value", pit.data() );
      group.appendChild( option );
    }

    root.appendChild( group );
  }

  doc.appendChild( root );

  // open file
  QFile* pFile = new QFile( m_file );

  m_fileState = pFile->open( IO_WriteOnly );

  if( !m_fileState )
  {
    delete pFile;
    return;
  }

  // write it out
  QTextStream textstream( pFile );
  doc.save( textstream, 0 );

  pFile->close();
  delete pFile;

  m_formatState = true;

}

