/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : ksettings.h
 */




#ifndef K_SETTINGS_H
#define K_SETTINGS_H

#include <qstring.h>
#include <qmap.h>

class QDomElement;

class KSettings
{
public:
  KSettings( const QString& version = "1.3", const QString& program_name = "k");

  virtual ~KSettings();

  const QString& version() const { return m_version; }
  const QString& file() const { return m_file; };
  const QString& format() const { return m_format; }
  bool fileState() const { return m_fileState; }
  bool formatState() const { return m_formatState; }
  const QString& currentGroup() const { return m_currentGroup; }

  void setFile( const QString& file_name ) { m_file = file_name; }
  virtual void setGroup( const QString& group ) { m_currentGroup = group; }
  const QString& group() const { return m_currentGroup; }

  // boolean data storage
  bool getBool( const QString& key, bool def = false );
  void setBool( const QString& key, bool value );
  // integer data storage
  long getNumber( const QString& key, long def = 0 );
  void setNumber( const QString& key, long value );
  // double data storage
  double getDouble( const QString& key, double def = 0.0 );
  void setDouble( const QString& key, double value );
  // string data storage
  QString getString( const QString& key, const QString& def = "NULL" );
  void setString( const QString& key, const QString& value );

  // remove a key/value from the preferences
  void removeKey( const QString& key ) { (m_groups[ m_currentGroup ]).remove( key ); }
  // remove the current group from the preferences
  void removeGroup() { m_groups.remove( m_currentGroup ); }

  // load the preferences from file
  bool loadData();
  // flush the preferences out to file
  bool flush();

protected:
  void readData();
  void writeData();
  void processGroup( QDomElement group );

protected:
  bool m_dirty;
  QString m_currentGroup;
  QString m_file;
  QString m_format;
  QString m_version;
  QString m_buffer;
  bool m_fileState;
  bool m_formatState;

  typedef QMap<QString, QString> PrefMap;
  QMap<QString, PrefMap> m_groups;

};


#endif /* K_SETTINGS_H */
