/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : options.h
 */




#ifndef KAF_OPTIONS_H
#define KAF_OPTIONS_H

#include "ksettings.h"

class Options : public KSettings
{
public:
  Options();
  ~Options();

  bool checkEventTick( int );
  bool checkProgressTick( int );

  static QString getKafVersion();
  static QString getMameBasedVersion();

  QString personalDirectory();
  QString tempDirectory();
  QString mameTempDirectory();
  QString mameXmlFilePath();
  QString mameTxtFilePath();
  QString mameFavoritesFilePath();
  QString mamePreviewFileType();
  QString mameIconFileType();
  QString mameVersion();

  QString mameGamesListHeader();
  bool setMameGamesListHeader( const QString& );

  QString mameGamesSupportedTextForParsing() { return "Total Supported:"; }

protected:
  virtual void setDefaults();

};


/* Options group */
#define G_GENERAL                    "General"
#define G_MAME                       "Mame"
#define G_MAME_X11                   "Mame X11"
#define G_MAME_XGL                   "Mame XGL"
#define G_MAME_SDL                   "Mame SDL"
#define G_DISPLAY                    "Display"
#define G_SOUND                      "Sound"
#define G_NETWORK                    "Network"
#define G_INPUT                      "Input"
#define G_VECTOR                     "Vector"
#define G_MISC                       "Misc"

/* General options */
#define O_PERSONAL_DIR               "Personal directory"
#define O_TEMP_DIR                   "Temporary directory"
#define O_CHECK_EVENT_TICK           "Check event every tick"
#define O_CHECK_PROGRESS_TICK        "Check progress every tick"
#define O_PREVIEW_FILE_TYPE          "Preview file type"
#define O_ICON_FILE_TYPE              "Icon file type"
#define O_LOAD_GAMES_INFO            "Load games information at startup"


/* Mame options */
#define O_MAME_EXE                   "Executable path"
#define O_MAME_VERSION               "Version"
#define O_MAME_BUILD                 "Build"
#define O_MAME_GAMES_LIST_VERSION    "Games list version"
#define O_MAME_GAMES_LIST_KAF_VERSION "Games list generated by KAF version"
#define O_MAME_GAMES_SUPPORTED       "Games supported"
#define O_MAME_ROMS_DIR              "Roms directory"
#define O_MAME_ICONS_DIR             "Icons directory"
#define O_MAME_SNAPS_DIR             "Snaps directory"
#define O_MAME_SAMPLES_DIR           "Samples directory"
#define O_MAME_INI_DIR               "Ini directory"
#define O_MAME_ARTWORK_DIR           "Artwork directory"
#define O_MAME_FLYERS_DIR            "Flyers directory"
#define O_MAME_CTRLR_DIR             "Ctrlr directory"
#define O_MAME_CHEAT_FILE            "Cheat file"
#define O_MAME_HISCORE_FILE          "Hiscore file"
#define O_MAME_HISTORY_FILE          "History file"
#define O_MAME_INFO_FILE             "Info file"
#define O_MAME_RENDER                "Render"
#define O_MAME_GAME_FILTER           "Game filter"
#define O_MAME_CUSTOM_OPTIONS        "Custom options"
#define O_MAME_ONLY_CUSTOM_OPTIONS   "Use only custom options"
#define O_MAME_LAST_GAME             "Last game selected"
#define O_MAME_PREVIEW_MODE          "Preview mode"
#define O_MAME_REMOVE_OPTIONS        "Remove options"

/* Mame X11 options */
#define O_X11_VIDEO_MODE             "Video mode"
#define O_X11_FULLSCREEN             "Fullscreen"
#define O_X11_GEOMETRY_WIDTH         "Geometry width"
#define O_X11_GEOMETRY_HEIGHT        "Geometry height"
#define O_X11_OFFSET_WIDTH           "Geometry offset width"
#define O_X11_OFFSET_HEIGHT          "Geometry offset height"
#define O_X11_KEEP_ASPECT_RATIO      "Keep aspect ratio"
#define O_X11_DISPLAY_ASPECT_RATIO   "Display aspect ratio"
#define O_X11_DISABLE_MODE           "Disable mode"
#define O_X11_SHOW_CURSOR            "Show cursor"
#define O_X11_MIT                    "Use MIT shared memory"
#define O_X11_FORCE_YUV              "Force YUV"
#define O_X11_FORCE_YV12             "Force YV12"
#define O_X11_WIDESCREEN             "Use widescreen"
#define O_X11_XSYNC                  "Use XSync"
#define O_X11_PRIVATE_COLOR_MAP      "Use private color map"
#define O_X11_XIL                    "Use XIL for scaling"
#define O_X11_XIL_MULTITHREAD        "Use multi threading for XIL"

/* Mame XGL options */
#define O_XGL_FULLSCREEN             "Use fullscreen mode"
#define O_XGL_CUSTOM_RESOLUTION      "Use custom resolution"
#define O_XGL_GEOMETRY_WIDTH         "Geometry width"
#define O_XGL_GEOMETRY_HEIGHT        "Geometry height"
#define O_XGL_OFFSET_WIDTH           "Geometry offset width"
#define O_XGL_OFFSET_HEIGHT          "Geometry offset height"
#define O_XGL_DOUBLE_BUFFERING       "Use double buffering"
#define O_XGL_USE_TEXTURE_SIZE       "Use texture size"
#define O_XGL_TEXTURE_SIZE           "Texture size"
#define O_XGL_FORCE_BLITTER          "Force blitter for true color modes"
#define O_XGL_FORCE_EXT78            "Force the usage of the GL extension #78"
#define O_XGL_BILINEAR_FILTER        "Use bilinear filtering"
#define O_XGL_DRAW_BITMAP            "Draw bitmap"
#define O_XGL_COLOR_MODULATION       "Use color modulation"
#define O_XGL_ALPHA_BLENDING         "Use alphablending"
#define O_XGL_ANTIALIAS              "Use antialiasing"
#define O_XGL_OPENGL_PATH            "OpenGL library"
#define O_XGL_GLU_PATH               "GLU library"

/* Mame SDL otions */
#define O_SDL_FULLSCREEN             "Use fullscreen mode"
#define O_SDL_CUSTOM_MODE            "Use custom mode"
#define O_SDL_MODE                   "Use mode number"

/* Display options */
#define O_DISPLAY_EFFECTS            "Video effects"
#define O_DISPLAY_SCANLINES          "Use scanlines"
#define O_DISPLAY_SLEEP_IDLE         "Sleep when idle"
#define O_DISPLAY_GAMMA              "Gamma correction"
#define O_DISPLAY_BRIGHTNESS         "Brightness correction"
#define O_DISPLAY_PAUSE_BRIGHTNESS   "Pause brightness"
#define O_DISPLAY_DISABLE_ROTATION   "Disable rotation"
#define O_DISPLAY_ROTATION           "Rotation type"
#define O_DISPLAY_FLIP_LR            "Flip left-right"
#define O_DISPLAY_FLIP_UD            "Flip upside-down"
#define O_DISPLAY_X_SCALE            "X-Scale"
#define O_DISPLAY_Y_SCALE            "Y-Scale"
#define O_DISPLAY_BPP                "Bpp"
#define O_DISPLAY_AUTO_DOUBLE        "Autodouble"
#define O_DISPLAY_ARG_SCALE          "Scale video to exactly this height"
#define O_DISPLAY_THROTTLE           "Throttle"
#define O_DISPLAY_AUTO_FRAME_SKIP    "Automatic frame skip"
#define O_DISPLAY_FRAME_SKIP_METHOD  "Automatic frame skip routine"
#define O_DISPLAY_NUM_FRAMES_TO_SKIP   "# frames to skip"
#define O_DISPLAY_MAX_NUM_FRAMES_TO_SKIP   "Max # frames to skip"

/* Sound options */
#define O_SOUND_ENABLE               "Enable sound"
#define O_SOUND_FAKE                 "Use fake sound"
#define O_SOUND_SAMPLES              "Use samples"
#define O_SOUND_SAMPLERATE           "Samplerate"
#define O_SOUND_VOLUME               "Volume"
#define O_SOUND_BUFFER               "Buffer"
#define O_SOUND_AUDIO_DEVICE         "Audio device"
#define O_SOUND_MIXER_DEVICE         "Mixer device"
#define O_SOUND_DSP_PLUGIN           "DSP plugin"
#define O_SOUND_MIXER_PLUGIN         "Mixer plugin"

/* Network options */
#define O_NETWORK_ENABLE             "Enable network"
#define O_NETWORK_MODE               "Network mode"
#define O_NETWORK_SERVERNAME         "Server name"
#define O_NETWORK_SERVERPORT         "Server port"
#define O_NETWORK_UDP_PORT           "UDP Port"
#define O_NETWORK_PLAYERS            "# players"
#define O_NETWORK_NETMAPKEY          "Use player 1 controls"
#define O_NETWORK_SYNC               "Parallel sync"
#define O_NETWORK_DEBUG              "Debug"

/* Input options */
#define O_INPUT_GRAB_MOUSE           "Grab mouse"
#define O_INPUT_GRAB_KEYBOARD        "Grab keyboard"
#define O_INPUT_WINKEYS              "Use winkeys"
#define O_INPUT_KEYMAP               "Keymap"
#define O_INPUT_JOYSTICK_TYPE        "Joystick type"
#define O_INPUT_ANALOG_JOYSTICK      "Analog joystick"
#define O_INPUT_JOYSTICK_DEVICE      "Joystick device"
#define O_INPUT_MOUSE                "Use Mouse"
#define O_INPUT_UGCI                 "Use UGCI Coin/Play support"
#define O_INPUT_USB_PAD              "Use USB pad"
#define O_INPUT_RAPID_FIRE           "Use rapid fire"
#define O_INPUT_CONTROLLER_CFG       "Controller preconfigure"

/* Vector options */
#define O_VECTOR_ANTIALIAS           "Use antialias"
#define O_VECTOR_TRANSLUCENCY        "Use translucency"
#define O_VECTOR_FIXED_RESOLUTION    "Use fixed resolution"
#define O_VECTOR_RESOLUTION          "Resolution"
#define O_VECTOR_BEAM                "Beam"
#define O_VECTOR_FLICKER             "Flicker"
#define O_VECTOR_INTENSITY           "Intensity"
#define O_VECTOR_GL_ANTIALIAS        "Use antialias in GL mode"
#define O_VECTOR_GL_DRAW_BITMAP      "Draw bitmap in GL mode"

/* Misc options */
#define O_MISC_CHEAT                 "Use cheat"
#define O_MISC_SKIP_DISCLAIMER       "Skip disclaimer"
#define O_MISC_SKIP_GAME_INFO        "Skip game info"
#define O_MISC_ARTWORK               "Use additional game artwork"
#define O_MISC_BACKDROPS             "Use backdrop artwork"
#define O_MISC_OVERLAYS              "Use overlat artwork"
#define O_MISC_BEZELS                "Use bezel artwork"
#define O_MISC_CROP_ARTWORK          "Crop artwork to game screen only"
#define O_MISC_ARTWORK_RESOLUTION    "Artwork resolution"



#endif /* KAF_OPTIONS_H */

