/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : wndbuildgameslist.cpp
 */




#include "wndbuildgameslist.h"
#include "pixmaps.h"

#include <qlabel.h>
#include <qtimer.h>
#include <qpushbutton.h>

#define KAF_TIMER_TICK         250



WndBuildGamesList::WndBuildGamesList( Options* pOptions, QWidget* parent )
  : GuiBuildGamesList( parent, "BuildGamesList Window", true )
{
  setIcon( Pixmaps::getMameIcon() );

  mp_build = new BuildGamesList( pOptions, this );

  init();

  connect( mp_build, SIGNAL( stateChanged( int ) ), this, SLOT( slotAdvanceState( int ) ) );

  connect( bCancel, SIGNAL( clicked() ), this, SLOT( slotCancel() ) );

  mp_tick = new QTimer( this );
  connect( mp_tick, SIGNAL( timeout() ), this, SLOT( slotTick() ) );
  resetTickState();

  slotBuild();
}

WndBuildGamesList::~WndBuildGamesList()
{
  if( mp_tick->isActive() )
    mp_tick->stop();

  delete mp_tick;

  if( mp_build->running() )
  {
    mp_build->wait();
  }

  delete mp_build;
}

void WndBuildGamesList::slotTick()
{
  switch( m_tickState )
  {
  case 0:
    m_tickState = 1;
    break;
  case 1:
    m_tickState = 0;
    break;
  default:
    m_tickState = 0;
  }

  labelPix->setPixmap( Pixmaps::getState( m_tickState ) );
}

void WndBuildGamesList::resetTickState()
{
  m_tickState = 0;
  labelPix->setPixmap( Pixmaps::getState( m_tickState ) );
}

void WndBuildGamesList::slotCancel()
{
  qDebug( "Build Games List - break thread." );
  if( mp_tick->isActive() )
    mp_tick->stop();
  m_tickState = 0;
  close();
}

void WndBuildGamesList::slotBuild()
{
  qDebug( "Build Games List - starting thread." );
  mp_tick->start( KAF_TIMER_TICK );
  mp_build->start();
}

void WndBuildGamesList::slotError()
{
  if( mp_tick->isActive() )
    mp_tick->stop();
  resetTickState();

  if( m_state == BuildGamesList::Dumping )
  {
    status1->setText( "Error occurred." );
    status2->setText( "Stopped." );
  }
  else if( m_state == BuildGamesList::Parsing )
  {
    status2->setText( "Error occurred." );
  }
  else
  {
    status1->setText( "Error occurred." );
    status2->setText( "Error occurred." );
  }
}

void WndBuildGamesList::init()
{
  m_state = BuildGamesList::Dumping;
  status1->setText( "Running..." );
  status2->setText( "Waiting..." );
}

void WndBuildGamesList::slotAdvanceState( int state )
{
  if( state == BuildGamesList::Error )
  {
    slotError();
    return;
  }
  else if( state == BuildGamesList::Dumping )
  {
    m_state = state;
    status1->setText( "Running..." );
  }
  else if( state == BuildGamesList::Parsing )
  {
    m_state = state;
    status1->setText( "Done." );
    status2->setText( "Running..." );
  }
  else if( state == BuildGamesList::Finished )
  {
    m_state = state;
    mp_tick->stop();
    status2->setText( "Done." );
    bCancel->setText( "Ok" );
    resetTickState();
    return;
  }
  else
  {
    // Errors
  }
}


