/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : wndinfo.cpp
 */


#include "wndinfo.h"
#include "pixmaps.h"
#include "game.h"
#include "options.h"
#include "icotoxpm.h"

#include <qlabel.h>
#include <qstring.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include <qfont.h>


WndInfo::WndInfo( Options* pOptions, QWidget* parent, const char* name )
  : GuiInfo( parent, name, false )
{
  setIcon( Pixmaps::getMameIcon() );

  setCaption( trUtf8( "KAF - Information" ) );

  mp_options = pOptions;

  connect( bClose, SIGNAL( clicked() ), this, SLOT( close() ) );

  QFont font = labelDescription->font();
  font.setBold( true );
  labelDescription->setFont( font );
}

WndInfo::~WndInfo()
{
}

void WndInfo::closeEvent( QCloseEvent* e )
{
  GuiInfo::closeEvent( e );
  emit( closing() );
}

void WndInfo::loadGameIcon( Game* pGame )
{
  QString sPrevGroup = mp_options->currentGroup();
  mp_options->setGroup( G_MAME );

  QString sFileIco = mp_options->getString( O_MAME_ICONS_DIR, "/usr/local/share/xmame/icons" );
  sFileIco += "/";
  sFileIco += pGame->name();
  sFileIco += mp_options->mameIconFileType();

  QPixmap pix = IcoToXpm::convert( sFileIco );

  if( pix.isNull() )
  {
    framePix->hide();
  }
  else
  {
    labelPix->setPixmap( pix );
    framePix->show();
  }

  mp_options->setGroup( sPrevGroup );
}

void WndInfo::slotShowInfo( Game* pGame )
{
  if( !pGame )
  {
    qWarning( "Game pointer is NULL in WndInfo::slotShowInfo()." );
    return;
  }

  QString sTmp = "";

  labelDescription->setText( pGame->description() );

  sTmp.sprintf( trUtf8( "%s - %s - %s.zip" ),
    pGame->manufacturer().latin1(), pGame->year().latin1(), pGame->name().latin1() );

  labelInfo->setText( sTmp );

  loadGameIcon( pGame );

  sTmp = pGame->info();

  if( sTmp.isEmpty() )
  {
    if( pGame->hasFlag( Game::Clone ) )
    {
      sTmp = "This game is a clone of rom '";
      sTmp += pGame->cloneof();
      sTmp += "'.";
    }
    else
    {
      sTmp = "There is no informations available for this game.";
    }
  }

  teInfo->setText( sTmp );
}
