/************************************************************************
 *                                                                      *
 * Project: KAF - Khelben Arcade Frontend                               *
 *                                                                      *
 * Author: Marco Mastroddi <marco.mastroddi@libero.it>                  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 ************************************************************************/

/*
 *    File    : wndpreferences.cpp
 */

#include "wndpreferences.h"
#include "wndmamepaths.h"
#include "options.h"

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qfiledialog.h>


WndPreferences::WndPreferences( Options* pOptions, QWidget* parent )
 : GuiPreferences( parent, "PreferencesDialog", true )
{
  mp_options = pOptions;

  connect( bOk, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
  connect( bCancel, SIGNAL( clicked() ), this, SLOT( slotCancel() ) );
  connect( bPersonalDir, SIGNAL( clicked() ), this, SLOT( slotSelectPersonalDir() ) );
  connect( bTempDir, SIGNAL( clicked() ), this, SLOT( slotSelectTempDir() ) );

  updateMenus();
}

WndPreferences::~WndPreferences()
{
}

void WndPreferences::slotOk()
{
  mp_options->setGroup( G_GENERAL );

  mp_options->setBool( O_LOAD_GAMES_INFO, cbLoadInfo->isChecked() );

  mp_options->setNumber( O_CHECK_EVENT_TICK, sbEventTick->value() );
  mp_options->setNumber( O_CHECK_PROGRESS_TICK, sbProgressTick->value() );

  WndMamePaths::setDirInOptions( mp_options, O_PERSONAL_DIR, lePersonalDir->text() );
  WndMamePaths::setDirInOptions( mp_options, O_TEMP_DIR, leTempDir->text() );

  done( 1 );
}

void WndPreferences::slotCancel()
{
  done( 0 );
}

void WndPreferences::updateMenus()
{
  mp_options->setGroup( G_GENERAL );

  cbLoadInfo->setChecked( mp_options->getBool( O_LOAD_GAMES_INFO, false ) );

  sbEventTick->setValue( mp_options->getNumber( O_CHECK_EVENT_TICK, 200 ) );
  sbProgressTick->setValue( mp_options->getNumber( O_CHECK_PROGRESS_TICK, 40 ) );

  lePersonalDir->setText( mp_options->personalDirectory() );
  leTempDir->setText( mp_options->tempDirectory() );

  mp_options->getString( O_PREVIEW_FILE_TYPE, "png" );
}

bool WndPreferences::selectDir( QLineEdit* ple, const QString& txt )
{
  QString sDir = QFileDialog::getExistingDirectory( ple->text(), this,
                   "SelectDirDialog", txt, true, false );

  if( sDir.isNull() || sDir.isEmpty() )
    return false;

  ple->setText( sDir );

  return true;
}

void WndPreferences::slotSelectPersonalDir()
{
  selectDir( lePersonalDir, trUtf8( "KAF - Select personal directory" ) );
}

void WndPreferences::slotSelectTempDir()
{
  selectDir( leTempDir, trUtf8( "KAF - Select temp directory" ) );
}
